@@ -3,7 +3,7 @@
  * Based on the rrdtool Python bindings for Python 2 from
  * Hye-Shik Chang <perky@fallin.lv>.
  *
- * Copyright 2012 Christian Jurk <commx@commx.ws>
+ * Copyright 2012 Christian Kroeger <commx@commx.ws>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as
@@ -157,13 +157,13 @@ convert_args(char *command, PyObject *args, char ***rrdtool_argv, int *rrdtool_a
         o = PyTuple_GET_ITEM(args, i);
 
         if (PyRRD_String_Check(o))
-            (*rrdtool_argv)[++argv_count] = PyRRD_String_AS_STRING(o);
+            (*rrdtool_argv)[++argv_count] = (char *)PyRRD_String_AS_STRING(o);
         else if (PyList_CheckExact(o)) {
             for (j = 0; j < PyList_Size(o); j++) {
                 lo = PyList_GetItem(o, j);
 
                 if (PyRRD_String_Check(lo))
-                    (*rrdtool_argv)[++argv_count] = PyRRD_String_AS_STRING(lo);
+                    (*rrdtool_argv)[++argv_count] = (char *)PyRRD_String_AS_STRING(lo);
                 else {
                     PyMem_Del(*rrdtool_argv);
                     PyErr_Format(PyExc_TypeError,
@@ -265,7 +265,7 @@ static char _rrdtool_create__doc__[] = "Create a new Round Robin Database.\n\n\
     [DS:ds-name[=mapped-ds-name[source-index]]:DST:heartbeat:min:max]\n\
     [RRA:CF:xff:steps:rows]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdcreate.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdcreate.en.html";
 
 static PyObject *
 _rrdtool_create(PyObject *Py_UNUSED(self), PyObject *args)
@@ -304,7 +304,7 @@ static char _rrdtool_dump__doc__[] = "Dump an RRD to XML.\n\n\
     file.rrd\n\
     [file.xml]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrddump.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrddump.en.html";
 
 static PyObject *
 _rrdtool_dump(PyObject *Py_UNUSED(self), PyObject *args)
@@ -343,7 +343,7 @@ static char _rrdtool_update__doc__[] = "Store a new set of values into\
    N|timestamp:value[:value...]\n\
    [timestamp:value[:value...] ...]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdupdate.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdupdate.en.html";
 
 static PyObject *
 _rrdtool_update(PyObject *Py_UNUSED(self), PyObject *args)
@@ -417,7 +417,7 @@ static char _rrdtool_fetch__doc__[] = "Fetch data from an RRD.\n\n\
     [-a|--align-start]\n\
     [-d|--daemon address]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdfetch.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdfetch.en.html";
 
 static PyObject *
 _rrdtool_fetch(PyObject *Py_UNUSED(self), PyObject *args)
@@ -495,7 +495,7 @@ static char _rrdtool_flushcached__doc__[] = "Flush RRD files from memory.\n\n\
     filename\n\
     [filename ...]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdflushcached.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdflushcached.en.html";
 
 static PyObject *
 _rrdtool_flushcached(PyObject *Py_UNUSED(self), PyObject *args)
@@ -587,7 +587,7 @@ static char _rrdtool_graph__doc__[] = "Create a graph based on one or more " \
     CDEF:vname=RPN expression\n\
     VDEF=vname:RPN expression\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdgraph.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdgraph.en.html";
 
 static PyObject *
 _rrdtool_graph(PyObject *Py_UNUSED(self), PyObject *args)
@@ -644,7 +644,7 @@ static char _rrdtool_graphv__doc__[] = "Create a graph based on one or more " \
   This function works the same way as 'graph', but will return a info\n\
   dictionary instead of None.\n\n\
   Full documentation can be found at (graphv section):\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdgraph.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdgraph.en.html";
 
 static PyObject *
 _rrdtool_graphv(PyObject *Py_UNUSED(self), PyObject *args)
@@ -689,7 +689,7 @@ static char _rrdtool_xport__doc__[] = "Dictionary representation of data " \
     [CDEF:vname=rpn-expression]\n\
     [XPORT:vname[:legend]]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdxport.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdxport.en.html";
 
 static PyObject *
 _rrdtool_xport(PyObject *Py_UNUSED(self), PyObject *args)
@@ -791,7 +791,7 @@ static char _rrdtool_tune__doc__[] = "Modify some basic properties of a " \
     [-d|--data-source-type ds-name:DST]\n\
     [-r|--data-source-rename old-name:new-name]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdtune.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdtune.en.html";
 
 static PyObject *
 _rrdtool_tune(PyObject *Py_UNUSED(self), PyObject *args)
@@ -829,7 +829,7 @@ static char _rrdtool_first__doc__[] = "Get the first UNIX timestamp of the "\
     [--rraindex number]\n\
     [-d|--daemon address]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdfirst.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdfirst.en.html";
 
 static PyObject *
 _rrdtool_first(PyObject *Py_UNUSED(self), PyObject *args)
@@ -864,7 +864,7 @@ static char _rrdtool_last__doc__[] = "Get the UNIX timestamp of the most "\
     filename\n\
     [-d|--daemon address]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdlast.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdlast.en.html";
 
 static PyObject *
 _rrdtool_last(PyObject *Py_UNUSED(self), PyObject *args)
@@ -901,7 +901,7 @@ static char _rrdtool_resize__doc__[] = "Modify the number of rows in a "\
     GROW|SHRINK\n\
     rows\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdlast.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdlast.en.html";
 
 static PyObject *
 _rrdtool_resize(PyObject *Py_UNUSED(self), PyObject *args)
@@ -939,7 +939,7 @@ static char _rrdtool_info__doc__[] = "Extract header information from an "\
     [-d|--daemon address]\n\
     [-F|--noflush]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdinfo.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdinfo.en.html";
 
 static PyObject *
 _rrdtool_info(PyObject *Py_UNUSED(self), PyObject *args)
@@ -976,7 +976,7 @@ static char _rrdtool_lastupdate__doc__[] = "Returns datetime and value stored "\
     filename\n\
     [-d|--daemon address]\n\n\
   Full documentation can be found at:\n\
-  http://oss.oetiker.ch/rrdtool/doc/rrdlastupdate.en.html";
+  https://oss.oetiker.ch/rrdtool/doc/rrdlastupdate.en.html";
 
 static PyObject *
 _rrdtool_lastupdate(PyObject *Py_UNUSED(self), PyObject *args)
@@ -1052,7 +1052,7 @@ _rrdtool_lastupdate(PyObject *Py_UNUSED(self), PyObject *args)
 
 #ifdef WITH_FETCH_CB
 
-/** An Python object which will hold an callable for fetch callbacks */
+/** A Python object which will hold a callable for fetch callbacks */
 static PyObject *_rrdtool_fetch_callable = NULL;
 
 static int
@@ -1143,7 +1143,7 @@ _rrdtool_fetch_cb_wrapper(
         rrd_set_error("expected 'start' key in callback return value to be "
             "of type int");
         goto gil_release_err;
-    } else if (PyObject_RichCompareBool(tmp, tmp_min_ts, Py_EQ) || 
+    } else if (PyObject_RichCompareBool(tmp, tmp_min_ts, Py_EQ) ||
                PyObject_RichCompareBool(tmp, po_start, Py_LT)) {
         rrd_set_error("expected 'start' value in callback return dict to be "
             "equal or earlier than passed start timestamp");
@@ -1181,7 +1181,7 @@ _rrdtool_fetch_cb_wrapper(
         unsigned int x = 0;
 
         while (PyDict_Next(tmp, &pos, &key, &value)) {
-            char *key_str = PyRRD_String_AS_STRING(key);
+            const char *key_str = PyRRD_String_AS_STRING(key);
 
             if (key_str == NULL) {
                 rrd_set_error("key of 'data' element from callback return "
@@ -1240,8 +1240,7 @@ _rrdtool_fetch_cb_wrapper(
 
                         if (exc_value != NULL) {
                             exc_value_str = PyObject_Str(exc_value);
-                            char *exc_str = PyRRD_String_AS_STRING(exc_value_str);
-                            rrd_set_error(exc_str);
+                            rrd_set_error((char *)PyRRD_String_AS_STRING(exc_value_str));
                             Py_DECREF(exc_value);
                         }
 
